#include "testlib.h"
#include <vector>
#include <utility>

const int MAX_TURNS = 1000;

template<typename T> void my_random_shuffle(std::vector<T> &a) {
  for (int i = (int)a.size() - 1; i >= 1; i--) {
    int j = rnd.next(i + 1);
    std::swap(a[i], a[j]);
  } 
}

int main(int argc, char *argv[]) {
  registerInteraction(argc, argv);
  int n = inf.readInt();
  int k = inf.readInt();
  std::vector<int> cs(n);
  for (int i = 0; i < n; i++) cs[i] = i + 1;
  my_random_shuffle(cs);
  std::vector<std::pair<int, int>> cards(n);
  for (int i = 0; i < k; i++) {
    cards[i] = {cs[i], 1};
  }
  for (int i = k; i < n; i++) {
    cards[i] = {cs[i], 0};
  }
  my_random_shuffle(cards);

  printf("%d %d\n", n, k);
  fflush(stdout);
  
  int cntL = k;
  int cntR = 0;
  int sizeR = 0;
  int turns = 0;
  while (turns < MAX_TURNS) {
    std::string sx = ouf.readLine();
    turns++;
    if (sx == "Finish") {
      if (cntL == cntR) {
        if (sizeR > 0 && cards.size() > 0)
            quitf(_ok, "Equal number of cards");
        else
            quitf(_wa, "Left or right is empty");
      } else {
        quitf(_wa, ("There are " + std::to_string(cntL) + " cards in the left and " + std::to_string(cntR) + " cards in the right").c_str());
      }
    }
    if (sx == "Reverse") {
      if (cards.size() == 0) {
          quitf(_wa, "Left is empty");
      }
      cntL -= cards[0].second == 1;
      cntL += cards[0].second == 0;
      cards[0].second ^= 1;
    } else if (sx == "Move") {
      if (cards.size() == 0) {
          quitf(_wa, "Left is empty");
      }
      cntL -= cards[0].second == 1;
      cntR += cards[0].second == 1;
      sizeR++;
      for (int i = 1; i < (int)cards.size(); i++) {
        cards[i - 1] = cards[i];
      }
      cards.erase(cards.end() - 1);
    } else if (sx.substr(0, 3) == "Up ") {
      int x = -1;
      try {
        x = std::stoi(sx.substr(3));
        if (1 > x || x > (int)cards.size()) {
          quitf(_wa, "Trying to move to the first place unexisting element");
        }
      } catch (std::exception e) {
        quitf(_wa, "Expected integer, but found %s", sx);
      }
      auto tmp = cards[x - 1];
      for (int i = x - 2; i >= 0; i--) {
        cards[i + 1] = cards[i];
      }
      cards[0] = tmp;
    } else {
        quitf(_wa, "Unexpected command");
    }
    printf("%d\n", cntR);
    fflush(stdout);
  }
  return 0;
}

