#include "testlib.h"
#include <map>
#include <set>
#include <unordered_set>
#include <queue>
#include <iostream>
#include <numeric>

using namespace std;

string s;
int l, r, k;
const int ddd = 'z' - 'a' + 1;

bool read_answer(InStream &stream) {
    string t = stream.readString();
    if (t == "Impossible") {
        stream.readEoln();
        stream.readEof();
        return false;
    }
    if (t.length() != s.length()) {
        stream.quitf(_wa, "length of the string must not be changed\n");
    }
    if (s.length() == 1 && (l > 0 || r > 0)) {
        stream.quitf(_wa, "should be impossible\n");
    }
    for (int j = 0; j < t.length(); j++) {
        if (!('a' <= t[j] && t[j] <= 'z')) stream.quitf(_wa, "incorrect char\n");
    }
    int pos = stream.readInt(1, s.length()) - 1;

    if (pos - l + r < 0 || pos + r - l >= s.length()) {
        stream.quitf(_wa, "out of bounds\n");
    }

    vector<int> changes(s.length());
    for (int i = 0; i < s.length(); i++) {
        if (s[i] >= t[i]) changes[i] = (s[i] - t[i]);
        else changes[i] = (s[i] + ddd - t[i]);
    }
    int all_changes = accumulate(changes.begin(), changes.end(), 0);

    if (all_changes > k || (all_changes % ddd != k % ddd)) {
        stream.quitf(_wa, "wrong number of changes\n");
    }


    int left_change = s.length();
    int right_change = -1;
    for (int i = 0; i < s.length(); i++) {
        if (s[i] != t[i]) {
            left_change = min(i, left_change);
            right_change = max(i, right_change);
        }
    }

    int max_moves = right_change - left_change;
    if (max_moves > l && max_moves > r) {
        stream.quitf(_wa, "number of moves between changes is larger than allowed\n");
    }

    if (left_change <= pos && pos <= right_change) {
        // pos -> right, right -> left
        if (right_change - pos <= r && max_moves <= l) {
            return true;
        }

        // pos -> left, left -> right
        if (pos - left_change <= l && max_moves <= r) {
            return true;
        }

        stream.quitf(_wa, "number of moves is larger than allowed\n");
    }

    if (pos < left_change) {
        if (right_change - pos <= r) {
            return true;
        }

        stream.quitf(_wa, "number of moves is larger than allowed (L)\n");
    }

    if (pos > right_change) {
        if (pos - left_change <= l) {
            return true;
        }

        stream.quitf(_wa, "number of moves is larger than allowed (R)\n");
    }

    stream.quitf(_fail, "unhandled case\n");
}

int main(int argc, char *argv[]) {
    registerTestlibCmd(argc, argv);
    s = inf.readString();
    l = inf.readInt();
    r = inf.readInt();
    k = inf.readInt();

    bool expected = read_answer(ans);
    bool actual = read_answer(ouf);
    if (expected && !actual)
        quitf(_wa, "jury has an answer but participant does not\n");
    else if (expected == actual)
        quitf(_ok, "correct\n");
    else
        quitf(_fail, "participant has found an answer where jury did not\n");
}